from indexed import Indexed
from signal_handlers import register_signal_handlers
from backends import get_search_backend